Resorbable PCEC/gelatin-bismuth doped bioglass-graphene oxide bilayer membranes for guided bone regeneration - IOPscience
Author: Ahmet Engin Pazarçeviren
Date: 2019-04-15

This site uses cookies. By continuing to use this site you agree to our use of cookies. To find out more, see our Privacy and Cookies policy.
Close this notification
Biomedical Materials

Purpose-led Publishing is a coalition of three not-for-profit publishers in the field of physical sciences: AIP Publishing, the American Physical Society and IOP Publishing.

Together, as publishers that will always put purpose above profit, we have defined a set of industry standards that underpin high-quality, ethical scholarly communications.

We are proudly declaring that science is our only shareholder.

Paper

# Resorbable PCEC/gelatin-bismuth doped bioglass-graphene oxide bilayer membranes for guided bone regeneration

Ahmet Engin Pazarçeviren1, Zafer Evis1, Dilek Keskin1,2 and Ayşen Tezcaner3,1,2

Published 15 April 2019 • © 2019 IOP Publishing Ltd
Biomedical Materials, Volume 14, Number 3 Citation Ahmet Engin Pazarçeviren et al 2019 Biomed. Mater. 14 035018 DOI 10.1088/1748-605X/ab007b

## Article metrics

773 Total downloads

## Submit

Submit to this Journal

## MathJax

Turn off MathJax Turn on MathJax

## Permissions

Get permission to re-use this article

## Share this article

Article and author information

## Author e-mails

tezcaner@metu.edu.tr

## Author affiliations

1 Department of Engineering Sciences, Middle East Technical University, Ankara, Turkey

2 Center of Excellence in Biomaterials and Tissue Engineering, Middle East Technical University, Ankara, Turkey

## Author notes

3 Author to whom any correspondence should be addressed.

## ORCID iDs

Ayşen Tezcaner
https://orcid.org/0000-0003-4292-5856

## Dates

1. Received 6 September 2018
2. Revised 16 January 2019
3. Accepted 21 January 2019
4. Published 15 April 2019

## Peer review information

Method: Single-anonymous
Revisions: 2
Screened for originality? Yes

Buy this article in print

Journal RSS
Sign up for new issue notifications
1748-605X/14/3/035018

## Abstract

Guided bone regeneration (GBR) is a therapeutic modality applied prior to dental implant placement to increase bone density at the defect site or during placement for directing bone growth around implant. In this study, an asymmetric, bilayer structure was prepared by covalently bonding a dense polycaprolactone-polyethylene glycol-polycaprolactone (PCEC) membrane layer with a hydrogel layer composed of bismuth doped bioactive glass (BG, 45S5) and graphene oxide (GO) particles incorporated in gelatin. Structural and mechanical properties (surface morphology and chemistry, thickness, degradation rate and tensile strength of GBR membranes) were studied. Membranes had a 3D structure having almost 1 mm thickness which is suitable for space filling. Highest tensile strength (TS) (1.71 ± 0.10 MPa, p < 0.001) was observed for membranes having the highest BG containing group (BG20) while lowest TS was observed (1.23 ± 0.11 MPa, p < 0.001) for BG8/GO2 samples. Similarly, hydrolytic degradation of BG20 involving bilayer structures was slower in phosphate buffered saline (PBS) (23% ± 5% in 4 weeks) than other GBR membranes while biodegraded at an equal rate in lipase (BG20 as 72% ± 3%, BG10 as 69% ± 1%, BG8/GO2 as 71% ± 7% and BG2/GO8 as 74% ± 8%). BG8/GO2, displayed lowest gelatin (GEL) release in PBS over 28 d period (175% ± 9% and 164% ± 10% mgGEL/gsample, p < 0.001). However, all bilayer membranes displayed a similar rate of degradation in lipase solution and also had similar mineral deposition ability in simulated body fluid. Significantly higher cell proliferation (p < 0.001) and osteogenic differentiation (p < 0.001) of human dental pulp stem cells were observed in BG20 and BG10 membrane groups than all other groups. On the other hand, GO presence decreased both mechanical and osteoinductive properties compared to pure BG counterparts. Collectively, amine introduced (aminolysis) synthetic dense PCEC layer was covalently bonded to composite hydrogel layer to obtain coherent bilayer membranes for GBR. They were successfully produced to have two layers designed to prevent fibrous tissue movement towards bone defect while enabling bone regeneration. BG20 membrane groups demonstrated higher calcium phosphate deposition TS, cellular growth and osteogenic differentiation.

Export citation and abstract BibTeX RIS

## Access this article

The computer you are using is not registered by an institution with a subscription to this article. Please choose one of the options below.

### Login

IOPscience login

Find out more about journal subscriptions at your site.

### Purchase from

Article Galaxy
CCC RightFind

Purchase this article from our trusted document delivery partners.

### Rent from

### Make a recommendation

To gain access to this content, please complete the Recommendation Form and we will follow up with your librarian or Institution on your behalf.

For corporate researchers we can also follow up directly with your R&D manager, or the information management contact at your company. Institutional subscribers have access to the current volume, plus a 10-year back file (where available).

Please wait… references are loading.
10.1088/1748-605X/ab007b

## You may also like

- Postdoctoral Fellow, Research Scientist and Instructor in Biomedical Optics and Medical Physics
  UT Southwestern Medical Center
- Applied Biophotonics Professor
  Western University: Department of Physics & Astronomy
- Assistant Professor of Physics (Tenure-Track)
  Department of Chemistry and Physics - Saint Mary's College in Notre Dame, Indiana
- More jobs Post a job